<?php
/**
 * Admin template for theme colors
 *
 * @package WordPress
 * @subpackage Back_My_Book
 * @since Back My Book 1.0
 */

function bmb_add_menu_profile_photo() {
	$page = add_theme_page(
	   __('Profile Photo', 'back_my_book'),
	   __('Profile Photo', 'back_my_book'),
	   'edit_themes',
	   'bmb-author-photo',
	   'bmb_theme_author_photo_settings'
	);
	add_action("load-$page", 'bmb_theme_author_photo_updates');
	add_action("admin_print_styles-$page", 'bmb_load_profile_styles');
}

function bmb_load_profile_styles() { ?>
	<style type="text/css">
		.profile {
			border:1px solid #ccc; height:300px; width:265px;
		}
		#bmb-profile-preview {
			background-repeat:no-repeat;
		}
	</style>
<?php }

add_action('admin_menu', 'bmb_add_menu_profile_photo');

// Resizes profile image to specified size
function bmb_resize_images($file, $nwidth,$nheight,$save_path,$crop='') {
	
	$info = pathinfo($file);
	$file_extension = $info['extension'];
	$quality = '75';
	$fileName = basename($file, ".{$file_extension}");

	$newName = $fileName."-profile.".$file_extension;
    
    if (file_exists($file)) {   // If The Script Was Able To Copy The Image To It's Permanent Location
		if ($file_extension == "jpg" || $file_extension == "jpeg" ) {
			$simg = imagecreatefromjpeg($file);
		} elseif ($file_extension== "gif") { 
			$simg = imagecreatefromgif($file);
		} elseif($file_extension == "png") {
			$simg = imagecreatefrompng($file); 
		} else {
			wp_die( 'File type, "' .$file_extension.'" not supported. Please use JPG, PNG or GIF');
			
		}
		$currwidth = imagesx($simg);   // Current Image Width 
		$currheight = imagesy($simg);    //Current Image Height 
		
		if($crop) {
			$dimg = imagecreatetruecolor($nwidth, $nheight);
			$wm = $currwidth /$nwidth;
			$hm = $currheight /$nheight;
			$h_height = $nheight/2;
			$w_height = $nwidth/2;
			
			if($currwidth > $currheight ) 
			{
			$adjusted_width =$currwidth / $hm;
			$half_width = $adjusted_width / 2;
			$int_width = $half_width - $w_height;
		
			imagecopyresampled($dimg ,$simg ,-$int_width,0,0,0, $adjusted_width, $nheight, $currwidth , $currheight );
			} 
			elseif(($currwidth < $currheight ) || ($currwidth == $currheight ))
			{
			$adjusted_height = $currheight / $wm;
			$half_height = $adjusted_height / 2;
			$int_height = $half_height - $h_height;
		
			imagecopyresampled($dimg , $simg ,0,-$int_height,0,0, $nwidth, $adjusted_height, $currwidth , $currheight );
			}else {
			imagecopyresampled($dimg , $simg ,0,0,0,0, $nwidth, $nheight, $currwidth , $currheight );
			}
		} else {
			if ($currheight > $currwidth) {   // If Height Is Greater Than Width
				$zoom = $nheight / $currheight;   // Length Ratio For Width 
				$newheight = $nheight;   // Height Is Equal To Max Height 
				$newwidth = round($currwidth * $zoom);   // Creates The New Width 
			} else {    // Otherwise, Assume Width Is Greater Than Height (Will Produce Same Result If Width Is Equal To Height) 
				$zoom = $nwidth / $currwidth;   // Length Ratio For Height 
				$newwidth = $nwidth;   // Width Is Equal To Max Width 
				$newheight = round($currheight * $zoom);   // Creates The New Height 
				if($newheight > $nheight) {
					$zoom = $nheight / $currheight;
					$newheight = $nheight;
					$newwidth = round($currwidth * $zoom);
				}
			}
			$dimg = imagecreatetruecolor($newwidth, $newheight);
			imagecopyresampled($dimg, $simg, 0, 0, 0, 0, $newwidth, $newheight, $currwidth, $currheight);
		}	
		
		if ($file_extension == "jpg" || $file_extension == "jpeg" || $file_extension == "gif" ) {
			imagejpeg($dimg, $save_path. '/' . $newName,$quality);   // Saving The Image
		} elseif($file_extension == "png") {
			imagepng($dimg, $save_path. '/' . $newName);   // Saving The Image
		}
		
		imagedestroy($simg);   // Destroying The Temporary Image 
		imagedestroy($dimg);   // Destroying The Other Temporary Image 
		
		// Set correct file permissions
		$stat = stat( dirname( $save_path. '/' . $newName ));
		$perms = $stat['mode'] & 0000666; //same permissions as parent folder, strip off the executable bits
		@ chmod( $save_path. '/' . $newName, $perms );
		
		return $newName;
	
    } 
}

function bmb_theme_author_photo_updates() {
	// See if the user has posted us some information
	if (!empty($_GET['reset'])) {	
		if ( check_admin_referer('bmb_profile_photo-reset') ) {
			$opt_val = get_option('bmb_author_profile');
			$file = ABSPATH.'wp-content/uploads/'.$opt_val;
			if (file_exists($file)) 
				unlink($file);
			delete_option('bmb_author_profile');
			wp_redirect(admin_url('themes.php?page=bmb-author-photo&reseted=true'));
		}
	} elseif ($_POST) {
		if ( check_admin_referer('bmb-author-profile-upload-update') ) {

			if ( !empty($_FILES) && isset($_POST['submit-photo']) ) {
				
				$overrides = array('test_form' => false);
				$file = wp_handle_upload($_FILES['import'], $overrides);
			
				if ( isset($file['error']) )
					wp_die( $file['error'] );
				
				$file = $file['file'];
				$upload_dir = wp_upload_dir();
				
				$profile_photo = bmb_resize_images($file, '265','300',$upload_dir['basedir']);
				
				$opt_val = get_option('bmb_author_profile');
				if ($opt_val) {
					$current_file = ABSPATH.'wp-content/uploads/'.$opt_val;
					if (file_exists($current_file)) 
						unlink($current_file);
				}
				
				update_option('bmb_author_profile', $profile_photo);
				
				unlink($file);
			}
			
			if (isset($_POST['custom_url'])) {
				$custom_url = $_POST['custom_url'];
				update_option('bmb_author_profile_url', $custom_url);
			}
			
			// wp_redirect(admin_url('themes.php?page=bmb-author-photo&updated=true'));

		}
	} 
}

function bmb_theme_author_photo_settings() {
    //must check that the user has the required capability 
    if (!current_user_can('manage_options'))
    {
      wp_die( __('You do not have sufficient permissions to access this page.') );
    }

    // Read in existing option value from database
    $opt_val = get_option('bmb_author_profile');
	$custom_url = get_option('bmb_author_profile_url');

	?>
	<?php if ( !empty($_GET['updated']) ) { ?>
	<div id="message" class="updated">
		<p><?php printf( __( 'Photo updated. <a href="%s" target="_blank">Visit your site</a> to see how it looks.' ), home_url( '/' ) ); ?></p>
	</div>
	<?php } ?>
	<?php if ( !empty($_GET['reseted']) ) { ?>
	<div id="message" class="updated">
		<p><?php printf( __( 'Photo profile removed successfully!' ), home_url( '/' ) ); ?></p>
	</div>
	<?php } ?>
	
	
	<div class="wrap">
		<form enctype="multipart/form-data" id="upload-form" method="post" action="">
		<div id="icon-themes" class="icon32"><br/></div>
		<h2>Profile Photo</h2>

				<table class="form-table">
				<tbody>
					<tr valign="top">
					<th scope="row"><?php _e('Preview'); ?></th>
						<td>
						<?php
						if ($opt_val != '' && file_exists(ABSPATH.'wp-content/uploads/'.$opt_val)) {
							$profile = get_bloginfo('wpurl').'/wp-content/uploads/'.$opt_val;
						} else {
							$profile = get_bloginfo('template_url').'/images/default_profile.jpg';
						} ?>
							<div id="bmb-profile-preview" class="profile" style="background-image: url('<?php echo $profile; ?>');">
					</td>
					</tr>
					<tr valign="top">
					<th scope="row"><?php _e( 'Upload Profile Photo' ); ?></th>
						<td width="270px">
							<fieldset>
							<legend class="screen-reader-text"><span><?php _e( 'Update Your Profile Photo' ); ?></span></legend>
								<label for="upload"><?php _e('Choose an image from your computer:'); ?></label><br /><input type="file" id="upload" name="import" />
							</fieldset>
						</td>
						<td>
							<p class="submit">
								<input type="submit" name="submit-photo" class="button-primary" value="<?php esc_attr_e('Upload'); ?>" />
							</p>
						</td>
					</tr>
				</tbody>
				</table>
				<?php wp_nonce_field('bmb-author-profile-upload-update'); ?>
			</form>
			
			<form enctype="multipart/form-data" id="upload-form" method="post" action="">
			<table class="form-table">
				<tbody>
					<?php if  ($opt_val) { ?>
					<tr valign="top">
					<th scope="row"><?php _e( 'Remove Image' ); ?></th>
					<td>
						<?php $urla = wp_nonce_url("themes.php?page=bmb-author-photo&reset=true",'bmb_profile_photo-reset'); ?>
						<p class="submit" style="margin:5px 0 0px 0px; padding:3px;"><a href="<?php echo $urla; ?>" class="button" ><?php esc_attr_e('Remove Profile Photo'); ?></a></p>
					</td>
					</tr>
					<?php } ?>
					<tr valign="top">
					<th scope="row"><?php _e( 'Add custom url' ); ?></th>
					<td>
						<input type="text" name="custom_url" id="custom_url" value="<?php echo esc_attr($custom_url) ?>" size="40" /><br/>
						<span class="small"><?php _e('Please include "<b>http://</b>" in your url.', 'backmybook'); ?></span>
					</td>
					</tr>
				</tbody>
				</table>
				<table>
					<tr valign="top">
						<td>
							<p class="submit">
								<input type="submit" name="submit" class="button" value="<?php esc_attr_e('Update'); ?>" />
							</p>
						</td>
					</tr>
				</table>
				<?php wp_nonce_field('bmb-author-profile-upload-update'); ?>
			</form>
	</div><!-- #wrapper -->
<?php
 }
